Package: hisse
Version: 2.1.11
Date: 2023-1-31
Title: Hidden State Speciation and Extinction
Authors@R: c(person("Jeremy", "Beaulieu", role=c("aut", "cre"),
                     email = "jmbeauli@uark.edu"),
                     person("Brian", "O'Meara", role=c("aut")),
		      person("Daniel", "Caetano", role=c("aut")),
			person("James", "Boyko", role=c("aut")),
			   person("Thais", "Vasconcelos", role=c("aut")))
Maintainer: Jeremy Beaulieu <jmbeauli@uark.edu>
Depends: ape, deSolve, GenSA, subplex, nloptr
Suggests: testthat, knitr, rmarkdown, markdown
Imports: parallel, phytools, data.table, igraph, methods, diversitree,
        paleotree, plotrix, geiger, phangorn, TreeSim, corHMM
Description: Sets up and executes a HiSSE model (Hidden State Speciation and Extinction) on a phylogeny and character sets to test for hidden shifts in trait dependent rates of diversification. Beaulieu and O'Meara (2016) <doi:10.1093/sysbio/syw022>.
License: GPL (>= 2)
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2023-02-06 20:57:47 UTC; jeremybeaulieu
Author: Jeremy Beaulieu [aut, cre],
  Brian O'Meara [aut],
  Daniel Caetano [aut],
  James Boyko [aut],
  Thais Vasconcelos [aut]
Repository: CRAN
Date/Publication: 2023-02-11 10:10:15 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 13:27:54 UTC; unix
Archs: hisse.so.dSYM
