useDynLib(hisse, .registration = TRUE)

export(hisse.old, hisse.null4.old, MarginRecon.old, MarginReconGeoSSE.old, SupportRegion.old, TransMatMaker.old, ParDrop, ParEqual, plot.hisse.states, SimulateHisse, SimToPhylo, GetModelAveRates, GeoHiSSE.old, TransMatMakerGeoHiSSE.old, SimulateGeoHiSSE, TranslateParsMakerGeoHiSSE, plot.geohisse.states, SupportRegionGeoSSE.old, GetAICWeights, MuHiSSE, TransMatMakerMuHiSSE, MarginReconMuHiSSE, SupportRegionMuHiSSE, GeoHiSSE, TransMatMakerGeoHiSSE, MarginReconGeoSSE, SupportRegionGeoSSE, generateMiSSEGreedyCombinations, makeHiSSELikelihood, plot.muhisse.states, MiSSE, MiSSEGreedy, MarginReconMiSSE, SupportRegionMiSSE, plot.misse.states, hisse, TransMatMakerHiSSE, MarginReconHiSSE, SupportRegionHiSSE, makeGeoHiSSELikelihood, PruneRedundantModels, GetFossils, AddFossilPoints, AddStratIntervals, ProcessSimSample, ProcessSimStrat, PlotMisseSpace, MiSSENet, TipCorrelation, SummarizeMiSSEGreedy)
import(ape, data.table, deSolve, GenSA, subplex, nloptr)
importFrom("parallel", "mclapply", "mcmapply")
importFrom("phytools", "nodeHeights", "fastAnc", "anc.ML", "getDescendants", "force.ultrametric")
importFrom("grDevices", "colorRampPalette", "nclass.Sturges", "rainbow", "dev.flush", "dev.hold")
importFrom("graphics", "hist", "par", "plot", "rect", "segments", "text", "lines", "plot.new", "plot.window", "points", "strwidth")
importFrom("methods", "hasArg")
importFrom("utils", "capture.output")
importFrom("stats", "dbeta", "density", "quantile", "reorder", "rexp", "runif", "weighted.mean", "rbinom", "median", "optimize", "setNames", "dist")
importFrom(paleotree, dateNodes)
importFrom("diversitree", "tree.classe")
importFrom("plotrix", "draw.arc")
importFrom("stats", "lm", "predict")
importFrom("geiger", "is.extinct")
importFrom("phangorn", "Ancestors")
importFrom(TreeSim, sim.bd.taxa)
importFrom(corHMM, corHMM)
importFrom(igraph, "graph.data.frame", "neighbors", "V")
S3method(print, hisse.old.fit)
S3method(print, hisse.null4.old.fit)
S3method(print, hisse.fit)
S3method(print, hisse.support)
S3method(print, hisse.states)
S3method(print, hisse.geosse.states)
S3method(print, geohisse.fit)
S3method(print, geohisse.old.fit)
S3method(print, muhisse.fit)
S3method(print, muhisse.states)
S3method(print, muhisse.support)
S3method(print, misse.fit)
S3method(print, misse.states)
S3method(print, misse.support)
S3method(plot, hisse.states)
S3method(plot, geohisse.states)
S3method(plot, muhisse.states)
S3method(plot, misse.states)
